@@ -10,7 +10,7 @@ AtteanX::Parser::Turtle - Turtle RDF Parser
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::Turtle version 0.021
+This document describes AtteanX::Parser::Turtle version 0.026
 
 =head1 SYNOPSIS
 
@@ -44,9 +44,10 @@ A boolean indicating whether term values should be canonicalized during parsing.
 
 =cut
 
-package AtteanX::Parser::Turtle 0.021 {
+package AtteanX::Parser::Turtle 0.026 {
 	use Moo;
 	use Types::Standard qw(Bool ArrayRef HashRef Str Maybe InstanceOf);
+	use Types::Namespace qw( NamespaceMap );
 	use utf8;
 	use Carp qw(carp);
 	use Encode qw(encode);
@@ -74,7 +75,7 @@ Returns true if the parser has a namespace map, false otherwise.
 
 =cut
 
-	has 'namespaces' => (is => 'rw', isa => Maybe[InstanceOf['URI::NamespaceMap']], predicate => 'has_namespaces');
+	has 'namespaces' => (is => 'rw', isa => Maybe[NamespaceMap], predicate => 'has_namespaces');
 	has	'_stack'	=> (
 		is => 'ro',
 		isa => ArrayRef,
@@ -128,11 +129,6 @@ the data read from the UTF-8 encoded byte string C<< $data >>.
 		$self->_parse($l);
 	}
 
-=item C<< parse_term_from_string( $bytes ) >>
-
-This method is deprecated, as the name was misleading.
-Calls should be replaced with C<< parse_term_from_bytes >>.
-	
 =item C<< parse_term_from_bytes ( $bytes, $base ) >>
 
 =item C<< parse_node ( $bytes, $base ) >>
@@ -142,11 +138,6 @@ serialization is found at the beginning of C<< $bytes >>.
 
 =cut
 
-	sub parse_term_from_string {
-		carp "parse_term_from_string is deprecated and will be removed in Attean 0.021 (use parse_term_from_bytes instead)";
-		return shift->parse_term_from_bytes(@_);
-	}
-	
 	sub parse_term_from_bytes {
 		my $self	= shift;
 		unless (ref($self)) {
@@ -589,7 +580,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2018 Gregory Todd Williams. This
+Copyright (c) 2014--2019 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
